@@ -27,7 +27,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 %EXPORT_TAGS = (DEFAULT => [qw(&user_sign_is_valid &calc_pub_key_id &encrypt &send_doc &get_docs &split_base64)]);
 
 BEGIN {
-  $VERSION = '0.1';
+  $VERSION = '0.2';
 }
 
 =head1 NAME
@@ -39,6 +39,27 @@ GPLVote::SignDoc::Client -  module for helping create GPLVote SignDoc client sof
  # In finction-oriented style.
  use GPLVote::SignDoc::Client;
 
+ if (user_sign_is_valid($public_key, $sign, $data)) {
+    print "Sign of document is CORRECT\n";
+ } else {
+    print "BAD SIGN!!!\n";
+ };
+
+ my $pub_key_id = calc_pub_key_id($public_key);
+
+ my $enc_data = encrypt($public_key, $data);
+
+
+ def get_one_doc {
+    my ($doc) = @_;
+
+    push(@global_array, $doc);
+ };
+
+ get_doc('123', \&get_one_doc);
+ foreach (my $doc (@global_array)) {
+    ... process $doc
+ };
  
 =head1 Methods
 
@@ -55,7 +76,7 @@ data - signing data for verify signature.
 
 Returning true if signature is valid.
 
-=head2 split_base64
+=head2 split_base64(base_64 string)
 
 Helping method for separate one long line Base64 on different lines with length 72 chars.
 
@@ -76,19 +97,27 @@ Send document to proxy server.
 document - hash with structured document description like:
 
 * type - type of document (for example, "SIGN_REQUEST")
+
 * site - client site identification name (for example, "www.site.com")
+
 * data - encrypted document data like JSON array of strings (for example, encode('["string data1", "string data 2", ...]'))
+
 * template - template for show document data, started from template type line (for example, "LIST\nTitle for data1\nTitle for data 2\n...")
+
 * doc_id - internal client document identificator. Will be present in answered SIGN document.
 
 client_password - client password
 
-=head2 get_doc(client_password, get_one_doc function)
+=head2 get_docs(client_password, get_one_doc function, unixtime from_time)
 
 client_password - client password
 
 function - reference to function with one argument: hash with structured document.
 
+from_time - unix_time of moment after that get all documents
+
+Return 1 if docs present.
+
 =head1 BUGS
 
 No known bugs, but this does not mean no bugs exist.
@@ -205,11 +234,14 @@ sub send_doc {
 };
 
 sub get_docs {
-  my ($client_password, $get_doc_func) = @_;
+  my ($client_password, $get_doc_func, $from_time) = @_;
 
+  $from_time = time() - 3600*24 if !defined($from_time);
+  
   my $doc_request = {
     type => 'CLIENT_REQUEST',
     site => 'test',
+    from_time => $from_time,
   };
   
   my $server = "http://signdoc.gplvote.org/get";
@@ -223,6 +255,7 @@ sub get_docs {
 
   my $resp = $ua->request($req);
 
+  my $docs_present;
   if (!$resp->is_success) {
     warn "HTTP request error ".$resp->code." - ".$resp->message;
   } else {
@@ -231,12 +264,15 @@ sub get_docs {
     if ($response->{status} eq '0') {
       # Перебираем документы и в зависимости от типа обрабатываем
       foreach my $doc (@{$response->{documents}}) {
+        $docs_present = 1;
         $get_doc_func->($doc) if defined($get_doc_func);
       };
     } else {
       warn "Bad request auth status";
     };
   };
+  
+  return($docs_present);
 };
 
 sub to_hash {
